<?php
/*
Plugin Name: Shopp + Clockwork
Description: Merchants who have a WordPress e-commerce store are notified of new orders via a text message to their mobile phone through Clockwork.
Version: 1.0.2
Plugin URI: http://optimizemyshopp.com
Author: Lorenzo Orlando Caum, Enzo12 LLC
Author URI: http://www.enzo12.com
License: GPLv2
*/
/* 
(CC BY 3.0) 2012  Lorenzo Orlando Caum  (email : hello@enzo12.com)

	This plugin is free software: you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation, either version 3 of the License, or
	(at your option) any later version.

	This plugin is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with this plugin.  If not, see <http://www.gnu.org/licenses/>. 
*/

require_once('inc/class-Clockwork.php');

Shopp_Clockwork::smartLoad();

class Shopp_Clockwork {
	public static $apikey;
	public static $prepmessage;
	public static $to;
	
	public static function smartLoad() {
		$instantiate = apply_filters('shoppClockworkLoadBasic', true);
		if ($instantiate) { new Shopp_Clockwork; }
	}
	
	public function __construct() {
		add_action('shopp_init', array($this, 'init'));
		add_action('shopp_order_success', array($this, 'create_clockwork_notification'));
		
		$this->apikey = get_option("shopp_clockwork_apikey");		
		$this->prepmessage = get_option("shopp_clockwork_prepmessage");
		$this->to = get_option("shopp_clockwork_to");
	}
	
	public function init() {
		wp_enqueue_style( 'shopp-clockwork-stylesheet', plugins_url( "css/shopp-clockwork.css", __FILE__ ), array(), '20130128' );
		
		add_action('admin_menu', array($this, 'admin_menu'));
	}
	
	public function admin_menu(){
		global $Shopp;
		$ShoppMenu = $Shopp->Flow->Admin->MainMenu;
		$page = add_submenu_page($ShoppMenu,__('Shopp + Clockwork', 'page title'), __('+ Clockwork','menu title'), defined('SHOPP_USERLEVEL') ? SHOPP_USERLEVEL : 'manage_options', 'shopp-clockwork', array($this, 'display_settings'));
	
        add_action( 'admin_print_styles-' . $page, 'admin_styles' );
    }
	
	public function admin_styles() {
       	wp_enqueue_style( 'shopp-clockwork-stylesheet' );
  	}
	
	public function create_clockwork_notification($Purchase) {
		global $wpdb;

		/*	
			Refer to Shopp Purchase API call: 	
			https://shopplugin.net/api/category/theme/shopp-purchase/
			
			Sample data that can be included in the mobile message:
		
				IP Address  =  $Purchase->ip
				Order ID  =  $Purchase->id
				Transaction ID  =  $Purchase->txnid
				Transaction Status  =  $Purchase->txnstatus
				Customer ID  =  $Purchase->customer
				First Name  =  $Purchase->firstname
				Last Name  =  $Purchase->lastname
				Email  =  $Purchase->email
				Phone Number  =  $Purchase->phone
				Company  =  $Purchase->company
				Payment Method  =  $Purchase->gateway
				Billing Address  =  $Purchase->address
				Billing Address 2  =  $Purchase->xaddress
				Billing City  =  $Purchase->city
				Billing State  =  $Purchase->state
				Billing Post Code  =  $Purchase->postcode
				Billing Country  =  $Purchase->country
				Shipping Address  =  $Purchase->shipaddress
				Shipping Address 2  =  $Purchase->shipxaddress
				Shipping City  =  $Purchase->shipcity
				Shipping State  =  $Purchase->shipstate
				Shipping Post Code  =  $Purchase->shippostcode
				Shipping Country  =  $Purchase->shipcountry
				Promotion  =  $Purchase->promos
				Discount  =  $Purchase->discount
				Subtotal  =  $Purchase->subtotal
				Shipping  =  $Purchase->freight
				Tax  =  $Purchase->tax
				Total  =  $Purchase->total

		*/
        
        $preparemessage = "\r\n Customer - $Purchase->firstname $Purchase->lastname \r\nEmail - $Purchase->email \r\nDestination - $Purchase->shipcity, $Purchase->shipstate, $Purchase->shipcountry \r\nTotal - $$Purchase->total";
        
        $clockwork = new Clockwork($this->apikey);
        
        $message = array( "to" => "$this->to", "message" => "$preparemessage" );
        $result = $clockwork->send( $message );
        
		}
	
	public function display_settings() {
		wp_nonce_field('shopp-clockwork');
		
		if(!empty($_POST['submit'])){
			$this->apikey = stripslashes($_POST['apikey']);
			$this->prepmessage = stripslashes($_POST['prepmessage']);
			$this->to = stripslashes($_POST['to']);

			update_option("shopp_clockwork_apikey", $this->apikey);
			update_option("shopp_clockwork_prepmessage", $this->prepmessage);
			update_option("shopp_clockwork_to", $this->to);

		}	
?>

<div class="wrap">
	<h2>Shopp + Clockwork</h2>
	<div class="postbox-container" style="width:65%;">
		<div class="metabox-holder">	

			<div id="shopp-clockwork-introduction" class="postbox">
				<h3 class="hndle"><span>Introduction</span></h3>
				<div class="inside">
					<p>This plugin integrates <a href="http://optimizemyshopp.com/go/shopp/" title="Learn more about Shopp">Shopp</a> with <a href="http://optimizemyshopp.com/go/clockwork/" title="Learn more about Clockwork">Clockwork</a>.</p> 
					<p>After a customer completes checkout, a merchant will be notified of the new order via text message.</p>
					<p><em>Your Clockwork account will be deducted a credit for each notification that is sent to your mobile phone.</em></p>
					<p><em>Your mobile service provider or cell phone company may charge you to receive a text message. Please ensure that you have a text messaging plan or equivalent. If you are not sure, please check with your service provider. We are not responsible for any service fees.</em></p>
					<strong>Acknowledgements</strong>
					<br />
					<p>Credit to Adam Sewell who wrote the original code that allowed data to be transferred from Shopp after checkout. This code has been extended for several other services. <a href="http://optimizemyshopp.com/go/adamsewell/" title="Learn about Shopp Toolbox">View Adam's latest project</a></p>
					<p>Credit to Clockwork who created the PHP API Wrapper for the Clockwork API. <a href="https://github.com/mediaburst/clockwork-php" title="Learn about the PHP API Wrapper for Clockwork">Learn more about the Clockwork API</a></p>
				</div>
			</div>

			<div id="shopp-clockwork-general-settings" class="postbox">
				<h3 class="hndle"><span>Setup Tutorial</span></h3>
				<div class="inside">
				<p>The videos below are designed to show you an overview of the plugin and how to gather the information that you need to get it running quickly.</p>
				<p>Pro-tip: After starting a video, click on the fullscreen button which appears to the right of the HD toggle.</p>
				<p><strong>A Walkthrough of the Integration between Shopp and Clockwork</strong><br /><br />Videos coming in a future version.
                </p>
				<br />
				<p><strong>How to Find Your Information for Clockwork</strong><br /><br />Videos coming in a future version.
				</p>
				</div>
			</div>
			
			<div id="shopp-clockwork-support-feedback" class="postbox">
				<h3 class="hndle"><span>Support & Feedback</span></h3>
				<div class="inside">
				<p>This is a 3rd-party integration.</p> 
				<p>This plugin is <strong>actively supported</strong>. Support is provided as a courtesy by Lorenzo Orlando Caum, Enzo12 LLC. If you have any questions or concerns, please open a <a href="http://optimizemyshopp.com/support/" title="Open a new support ticket with Optimize My Shopp">new support ticket</a> via our Help Desk.</p>
                <p>You can share feedback via this a <a href="http://optimizemyshopp.com/go/shopp-extensions-survey/" title="Take a super short survey">short survey</a>. Takes less 3 than minutes -- we promise!</p>
                <p>Feeling generous? Please consider <a href="http://optimizemyshopp.com/go/donate-shopp-clockwork/" title="Say thank you by purchasing Lorenzo a Redbull">buying me a Redbull</a>, <a href="http://optimizemyshopp.com/go/amazonwishlist/" title="Say thank you by gifting Lorenzo a book">ordering me a book</a> from my Amazon Wishlist, or <a href="http://optimizemyshopp.com/go/tip-shopp-help-desk/" title="Say thank you by tipping Lorenzo via the Shopp Help Desk">tipping me</a> through the Shopp Help Desk.</p>
				</div>
			</div>
			
			<div id="shopp-clockwork-settings" class="postbox">
				<h3 class="hndle"><span>Clockwork Settings</span></h3>
				<div class="inside">
                    <p>Tutorial videos will be added in a future version of this plugin. Your API Key can be found in your Clockwork account. The phone number that you enter should include your country code.</p>
					<p>The message field that appear below are <strong>disabled</strong>.</p> 
					<p>Shopp + Clockwork will send new order information in the following format:</p>
					<p>MSG: <br />
					Customer - First name Last name<br />
					Email - Email<br />
					Destination - City, State/Province, Country<br />
					Total - Order Total</p>
					<p>
                    <form action="" method="post">
					<table>
					<tr>
						<th>API Key:</th>
						<td><input type="text" name="apikey" size="35" value="<?php echo $this->apikey; ?>" /></td>
					</tr>
					<tr>
						<th>Message</th>
						<td><input type="text" name="prepmessage" size="35" value="<?php echo $this->prepmessage; ?>" disabled="disabled" /></td>
					</tr>
					<tr>
						<th>Mobile Number</th>
						<td><input type="text" name="to" size="35" value="<?php echo $this->to; ?>" /></td>
					</tr>		
					</table>
					<input type="submit" class="button-primary" value="Save Settings" name="submit" />
					</form>
                    </p>
				</div>
			</div>
			
			<div id="shopp-clockwork-about-the-author" class="postbox">
				<h3 class="hndle"><span>About the Author</span></h3>
				<div class="inside">
					<table border="0" width="100%">
   					 	<tr>
                            <td width="70%"><div><img style="padding: 0px 15px 0px 0px; float:left" src="<?php echo plugins_url( 'shopp-clockwork/images/lorenzo-orlando-caum-shopp-wordpress-150x150.jpg' , dirname(__FILE__) ); ?>" border="0" alt="Founder of Enzo12 LLC" width="150" height="150">
                                <p><a href="http://twitter.com/lorenzocaum" title="Follow @lorenzocaum">@lorenzocaum</a> is an entrepreneur and a marketer.</p>
                                <p>Lorenzo contributes to the <a href="http://optimizemyshopp.com/go/shopp/" title="Visit shopplugin.net">Shopp</a> project as a member of the support team. He has written several  <a href="http://optimizemyshopp.com/resources/#shopp-extensions" title="View free WordPress plugins for Shopp">WordPress extensions for Shopp</a>. His latest project is <a href="http://optimizemyshopp.com/go/shopp101/" title="Shopp 101 -- video tutorials for Shopp">video tutorials for Shopp</a>.</p>
                                <p>He is the founder of Enzo12 LLC, a <a href="http://enzo12.com" title="Enzo12 LLC">web engineering firm</a> in Tampa, FL. If you would like to know more about Lorenzo, you can <a href="http://twitter.com/lorenzocaum">follow him on Twitter</a> or <a href="http://lorenzocaum.com" title="Read Lorenzo's blog">check out his blog</a>.</p></div></td>
                            <td width="30%"></td>
   						</tr>
					</table>
				</div>
			</div>

		</div>
	</div>

	<div class="postbox-container" style="width:25%;">
		<div class="metabox-holder">
				
			<div id="shopp-clockwork-donate" class="postbox">
				<h3 class="hndle"><span><strong>Make a Donation!</strong></span></h3>
				<div class="inside">
					<p>Hi friend!</p>
					<p>If this plugin is helpful to you, then please <a href="http://optimizemyshopp.com/go/donate-shopp-clockwork/" title="Say thank you by purchasing Lorenzo a Redbull">buy me a Redbull</a>.</p> 
                    <p>Why not <a href="http://optimizemyshopp.com/go/amazonwishlist/" title="Say thank you by gifting Lorenzo a book">order me a book</a> from my Amazon Wishlist.</p>
                    <p>You can also <a href="http://optimizemyshopp.com/go/tip-shopp-help-desk/" title="Say thank you by tipping Lorenzo via the Shopp Help Desk">tip me</a> through the Shopp Help Desk.</p>
					<p>Your kindness is appreciated and will go towards <em>continued development</em> of the Shopp + Clockwork plugin.</p>
				</div>
			</div>
			
			<div id="shopp-clockwork-subscribe" class="postbox">
				<h3 class="hndle"><span>Free Email Updates</span></h3>
				<div class="inside">
					<p>Get infrequent email updates delivered right to your inbox about getting the most from Shopp.</p>
					<div id="optin">
					<p>
					<form action="http://optimizemyshopp.us2.list-manage1.com/subscribe/post?u=5991854e8288cad7823e23d2e&amp;id=0719c3f096" method="post" target="_blank">
					<input type="text" name="EMAIL" class="email" value="Enter your email" onfocus="if(this.value==this.defaultValue)this.value='';" onblur="if(this.value=='')this.value=this.defaultValue;" />
					<input name="submit" class="button-primary" type="submit" value="Get Started!" />
					</form>
					</p>
					</div>
				</div>
			</div>
					
			<div id="shopp-clockwork-have-a-question" class="postbox">
				<h3 class="hndle"><span>Have a Question?</span></h3>
				<div class="inside">
                    <p>Open a <a href="http://optimizemyshopp.com/support/" title="Open a new support ticket with Optimize My Shopp">new support ticket</a> for Shopp + Clockwork</p>
                    <p>Learn about <a href="http://optimizemyshopp.com/resources/" title="Learn about extra Shopp resources">additional Shopp resources</a></p>
                    <p>Want awesome support from the Shopp Help Desk? <a title="How to Get Awesome Support on the Shopp Help Desk" href="http://optimizemyshopp.com/blog/how-to-get-awesome-support-from-the-shopp-help-desk/">Click here to read the post</a></p>
				</div>
			</div>

			<div id="shopp-clockwork-news-from-oms" class="postbox">
				<h3 class="hndle"><span>News from Optimize My Shopp</span></h3>
				<div class="inside">
				<p>Free eBook<br /> <a href="http://optimizemyshopp.com/newsletter/" title="Receive your free eBook delivered instantly to your inbox">10 Steps to a More Secure WordPress</a></p>
				<p>White Papers<br /> <a href="http://optimizemyshopp.com/resources/white-papers/" title="Get your free white paper on creating a fast Shopp website">Speeding up your Shopp E-commerce Website</a><br /><a href="http://optimizemyshopp.com/resources/white-papers/" title="Get your free white paper on using Shopp with caching plugins">Shopp + Caching Plugins</a></p>
				<?php _e('Recent posts from the blog'); ?>
				<?php
				include_once(ABSPATH . WPINC . '/feed.php');
				$rss = fetch_feed('http://feeds.feedburner.com/optimizemyshopp');
				if (!is_wp_error( $rss ) ) : 
    			$maxitems = $rss->get_item_quantity(7); 
    			$rss_items = $rss->get_items(0, $maxitems); 
				endif;
				?>
				<ul>
    			<?php if ($maxitems == 0) echo '<li>No items.</li>';
    			else
    			foreach ( $rss_items as $item ) : ?>
    			<li>
        		<a href='<?php echo esc_url( $item->get_permalink() ); ?>'
        		title='<?php echo 'Posted '.$item->get_date('j F Y | g:i a'); ?>'>
        		<?php echo esc_html( $item->get_title() ); ?></a>
    			</li>
    			<?php endforeach; ?>
				</ul>
				</div>
			</div>			
			
			<div id="shopp-clockwork-recommendations" class="postbox">
				<h3 class="hndle"><span>Recommended</span></h3>
				<div class="inside">
                    <p>Need a Shopp developer to help you with your online store? <br /><a href="http://optimizemyshopp.com/store/wordpress-consulting/" title="Hire a Shopp developer today">Get in touch today</a></p>
                    <p>What do you think about video tutorials for Shopp? <br /><a href="http://optimizemyshopp.com/go/shopp101/" title="Learn more about Shopp video tutorials">Online lessons and video tutorials for Shopp</a></p>
				</div>
			</div>

		</div>
		<br /><br /><br />
	</div>
</div>
<?php	
	}
}